# Generated by Django 4.2.23 on 2026-01-05 16:18

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_user_chemicals", "0006_userchemical_trade_name"),
    ]

    operations = [
        migrations.RenameField(
            model_name="chemicalrequest",
            old_name="chemical_name",
            new_name="name",
        ),
        migrations.RemoveField(
            model_name="chemicalrequest",
            name="trade_name",
        ),
        migrations.RemoveField(
            model_name="userchemical",
            name="trade_name",
        ),
    ]
