# Generated by Django 4.2.23 on 2025-09-26 13:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_user_chemicals", "0003_remove_chemicalrequest_health_hazards"),
    ]

    operations = [
        migrations.AddField(
            model_name="userchemical",
            name="trade_name",
            field=models.CharField(
                blank=True, help_text="Manufacturer/labeled name for this material", max_length=255, null=True
            ),
        ),
    ]
