{% extends 'base.html' %}
{% block title %}User Chemicals Home{% endblock %}
{% block content %}
    <div class="container-fluid">
        <h1>User Chemicals Dashboard</h1>
        <div class="row">
            <!-- User Actions -->
            <div class="col-md-6">
                <div class="panel panel-default">
                    <div class="panel-heading">
                        <h3 class="panel-title">My Activities</h3>
                    </div>
                    <div class="list-group">
                        <a href="{% url 'chemical_request' %}" class="list-group-item">
                            <i class="glyphicon glyphicon-plus-sign"></i> Request New Material Approval
                        </a>
                        <a href="{% url 'view_requests' %}" class="list-group-item">
                            <i class="glyphicon glyphicon-list-alt"></i> View My Material Requests
                        </a>
                        <a href="{% url 'my_chemicals' %}" class="list-group-item">
                            <i class="glyphicon glyphicon-filter"></i> View My Chemical Inventory
                        </a>
                    </div>
                </div>
            </div>
            <!-- Staff Actions -->
            {% if user.is_staff %}
                <div class="col-md-6">
                    <div class="panel panel-primary">
                        <div class="panel-heading">
                            <h3 class="panel-title">Administration</h3>
                        </div>
                        <div class="list-group">
                            <a href="{% url 'view_requests' %}" class="list-group-item">
                                <i class="glyphicon glyphicon-tasks"></i> Review Material Requests
                            </a>
                            <a href="{% url 'user_chemicals' %}" class="list-group-item">
                                <i class="glyphicon glyphicon-th-list"></i> Full Chemical Inventory
                            </a>
                            <a href="{% url 'add_user_chemical' %}" class="list-group-item">
                                <i class="glyphicon glyphicon-plus"></i> Add Item to Inventory
                            </a>
                            <a href="{% url 'add_chemical' %}" class="list-group-item">
                                <i class="glyphicon glyphicon-book"></i> Add New Chemical Definition
                            </a>
                            <a href="{% url 'safety_data_sheets' %}" class="list-group-item">
                                <i class="glyphicon glyphicon-tint"></i> View SDS Repository
                            </a>
                        </div>
                    </div>
                </div>
            {% endif %}
        </div>
    </div>
{% endblock %}
