# Generated by Django 4.2.23 on 2025-09-04 15:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_user_chemicals", "0002_chemicallocation_remove_chemicalrequest_corrosive_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="chemicalrequest",
            name="health_hazards",
        ),
    ]
