# Generated by Django 4.2.23 on 2026-01-06 15:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_user_chemicals", "0007_rename_chemical_name_chemicalrequest_name_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="userchemical",
            name="history",
            field=models.TextField(blank=True, default=""),
        ),
    ]
