# Generated by Django 4.2.27 on 2026-01-16 16:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("NEMO_user_chemicals", "0008_userchemical_history"),
    ]

    operations = [
        migrations.AlterField(
            model_name="chemicalrequest",
            name="cas",
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
